Crate crate_crypto_internal_eth_kzg_bls12_381

Crate crate_crypto_internal_eth_kzg_bls12_381 

Re-exports

pub use ff;
pub use group;

Modules

batch_addition
batch_inversion
fixed_base_msm
fixed_base_msm_window
lincomb

Functions

batch_normalize_points
Generic utility to batch-normalize projective points for any curve implementing PrimeCurveAffine.
g1_batch_normalize
Converts Projective points to normalized points efficiently.
g2_batch_normalize
Efficiently batch-normalizes a slice of G2 projective points to their affine representation.
multi_pairings
Checks whether the product of pairings over the given G1 × G2 pairs equals the identity.
reduce_bytes_to_scalar_bias
Reduces bytes to be a value less than the scalar modulus.

Type Aliases

G1Point
Affine representation of a point in the BLS12-381 G1 curve group.
G1Projective
Projective representation of a point in the BLS12-381 G1 curve group.
G2Point
Affine representation of a point in the BLS12-381 G2 curve group.
G2Prepared
Precomputed G2 point for efficient pairing computations.
G2Projective
Projective representation of a point in the BLS12-381 G2 curve group.
Scalar
Scalar field element for the BLS12-381 curve.